==> activity-center-api-0.9.5.9-zbq-20190416.072059-16-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/commercial/finance/config/RspFinanceConfigDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.commercial.finance.config;

import cn.com.duiba.tuia.activity.center.api.dto.commercial.finance.FinanceConfigDto;

import java.io.Serializable;
import java.util.List;

/**
 * TODO 注释
 *
 * @author zhangbaiqiang
 * @date 2019-04-12
 */
public class RspFinanceConfigDto implements Serializable {
    private static final long serialVersionUID = 4629961471348202431L;

    /**
     * 媒体id
     */
    private Long appId;

    private String appName;


    private Integer unitType;

    private String unitDesc;

    private String unitName;

    private Integer digits;

    /**
     * 周期数
     */
    private Integer stageAmount;


    private List<FinanceConfigDto> stages;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getUnitType() {
        return unitType;
    }

    public void setUnitType(Integer unitType) {
        this.unitType = unitType;
    }

    public String getUnitDesc() {
        return unitDesc;
    }

    public void setUnitDesc(String unitDesc) {
        this.unitDesc = unitDesc;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Integer getDigits() {
        return digits;
    }

    public void setDigits(Integer digits) {
        this.digits = digits;
    }

    public Integer getStageAmount() {
        return stageAmount;
    }

    public void setStageAmount(Integer stageAmount) {
        this.stageAmount = stageAmount;
    }

    public List<FinanceConfigDto> getStages() {
        return stages;
    }

    public void setStages(List<FinanceConfigDto> stages) {
        this.stages = stages;
    }
}

==> activity-center-api-0.9.5.13-zbq-20190425.074123-2-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/commercial/finance/config/RspFinanceConfigDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.commercial.finance.config;

import cn.com.duiba.tuia.activity.center.api.dto.commercial.finance.FinanceConfigDto;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.List;

/**
 * [深度互动]媒体新增/更新响应
 *
 * @author zhangbaiqiang
 * @date 2019-04-12
 */
@ApiModel
public class RspFinanceConfigDto implements Serializable {
    private static final long serialVersionUID = 4629961471348202431L;

    @ApiModelProperty("媒体id")
    private Long appId;

    @ApiModelProperty("媒体名称")
    private String appName;

    @ApiModelProperty("预算单位(整数)")
    private Integer unitType;

    @ApiModelProperty("预算单位(字符串)")
    private String unitDesc;

    @ApiModelProperty("虚拟货币名称")
    private String unitName;

    @ApiModelProperty("奖励小数位数")
    private Integer digits;

    @ApiModelProperty("周期总数")
    private Integer stageAmount;

    @ApiModelProperty("周期")
    private List<FinanceConfigDto> stages;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getUnitType() {
        return unitType;
    }

    public void setUnitType(Integer unitType) {
        this.unitType = unitType;
    }

    public String getUnitDesc() {
        return unitDesc;
    }

    public void setUnitDesc(String unitDesc) {
        this.unitDesc = unitDesc;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Integer getDigits() {
        return digits;
    }

    public void setDigits(Integer digits) {
        this.digits = digits;
    }

    public Integer getStageAmount() {
        return stageAmount;
    }

    public void setStageAmount(Integer stageAmount) {
        this.stageAmount = stageAmount;
    }

    public List<FinanceConfigDto> getStages() {
        return stages;
    }

    public void setStages(List<FinanceConfigDto> stages) {
        this.stages = stages;
    }
}
